@@ -1,9 +1,8 @@
-from bigxml.handler import XMLHandler, xml_handle_element, xml_handle_text
+from bigxml.handler_marker import xml_handle_element, xml_handle_text
 from bigxml.parser import Parser
 
 __all__ = (
     "Parser",
-    "XMLHandler",
     "xml_handle_element",
     "xml_handle_text",
 )
